@@ -17,8 +17,9 @@
 
 import os
 
-from gi.repository import GLib, Gtk, GObject, Handy
+from gi.repository import Adw, GLib, Gtk, GObject
 
+from . import utils
 from . import logger
 from .place import PortfolioPlace
 from .devices import PortfolioDevices
@@ -77,20 +78,18 @@ class PortfolioPlaces(Gtk.Stack):
         # begin UI structure
 
         self._groups_box = Gtk.Box()
-        self._groups_box.props.expand = True
         self._groups_box.props.visible = True
         self._groups_box.props.orientation = Gtk.Orientation.VERTICAL
 
         self._message_box = Gtk.Box()
-        self._message_box.props.expand = True
         self._message_box.props.visible = True
         self._message_box.props.orientation = Gtk.Orientation.VERTICAL
 
-        self._places_group = Handy.PreferencesGroup()
+        self._places_group = Adw.PreferencesGroup()
         self._places_group.props.title = _("Places")
         self._places_group.props.visible = True
 
-        self._devices_group = Handy.PreferencesGroup()
+        self._devices_group = Adw.PreferencesGroup()
         self._devices_group.props.title = _("Devices")
         self._devices_group.props.visible = True
         self._devices_group.get_style_context().add_class("devices-group")
@@ -165,18 +164,20 @@ class PortfolioPlaces(Gtk.Stack):
                 self.PORTFOLIO_SYSTEM_DIR_FLATPAK,
             )
 
-        self._groups_box.add(self._places_group)
-        self._groups_box.add(self._devices_group)
+        self._groups_box.append(self._places_group)
+        self._groups_box.append(self._devices_group)
+
+        self._places_listbox = utils.find_child_by_id(self._places_group, "listbox")
+        self._devices_listbox = utils.find_child_by_id(self._devices_group, "listbox")
 
         # no places message
 
         message = Gtk.Label()
-        message.props.expand = True
         message.props.visible = True
         message.props.label = _("No places found")
         message.get_style_context().add_class("no-places")
 
-        self._message_box.add(message)
+        self._message_box.append(message)
 
         # finalize UI structure
 
@@ -197,8 +198,8 @@ class PortfolioPlaces(Gtk.Stack):
         self._update_device_group_visibility()
 
     def _update_stack_visibility(self):
-        groups = len(self._places_group.get_children())
-        devices = len(self._devices_group.get_children())
+        groups = len(list(self._places_listbox))
+        devices = len(list(self._devices_listbox))
 
         if not groups and not devices:
             self.set_visible_child_name("message")
@@ -206,11 +207,11 @@ class PortfolioPlaces(Gtk.Stack):
             self.set_visible_child_name("groups")
 
     def _update_places_group_visibility(self):
-        visible = len(self._places_group.get_children()) >= 1
+        visible = len(list(self._places_listbox)) >= 1
         self._places_group.props.visible = visible
 
     def _update_device_group_visibility(self):
-        visible = len(self._devices_group.get_children()) >= 1
+        visible = len(list(self._devices_listbox)) >= 1
         self._devices_group.props.visible = visible
 
     def _get_permissions(self):
@@ -249,9 +250,9 @@ class PortfolioPlaces(Gtk.Stack):
 
     def _add_place(self, group, icon, name, path):
         place = PortfolioPlace()
-        place.set_icon_name(icon)
+        place.set_custom_icon_name(icon)
         place.set_title(name)
-        place.set_subtitle(path)
+        place.set_subtitle_sately(path)
         place.path = path
         place.props.activatable = True
         place.connect("activated", self._on_place_activated)
@@ -259,8 +260,8 @@ class PortfolioPlaces(Gtk.Stack):
 
         return place
 
-    def _find_place_by_device_uuid(self, group, device):
-        for place in group.get_children():
+    def _find_place_by_device_uuid(self, listbox, device):
+        for place in listbox:
             if place.uuid == device.uuid:
                 return place
         return None
@@ -283,12 +284,12 @@ class PortfolioPlaces(Gtk.Stack):
             return
 
         if self._filter_device(device):
-            place.destroy()
+            self._devices_group.remove(place)
             return
 
         place.path = device.mount_point
         place.set_title(device.label)
-        place.set_subtitle(device.mount_point)
+        place.set_subtitle_sately(device.mount_point)
 
     def _on_place_activated(self, place):
         if place.path is not None:
@@ -346,10 +347,10 @@ class PortfolioPlaces(Gtk.Stack):
 
     def _on_device_removed(self, devices, device):
         logger.debug(f"removed {device}")
-        place = self._find_place_by_device_uuid(self._devices_group, device)
+        place = self._find_place_by_device_uuid(self._devices_listbox, device)
 
         if place is not None:
-            place.destroy()
+            self._devices_group.remove(place)
 
         self.emit("removed", device.mount_point, device.safely_removed)
 
@@ -357,7 +358,7 @@ class PortfolioPlaces(Gtk.Stack):
 
     def _on_device_updated(self, device):
         logger.debug(f"updated {device}")
-        place = self._find_place_by_device_uuid(self._devices_group, device)
+        place = self._find_place_by_device_uuid(self._devices_listbox, device)
         self._update_place_from_device(place, device)
         self._update_visibility()
 
