@@ -18,7 +18,7 @@
 import os
 import re
 
-from gi.repository import GLib
+from gi.repository import GLib, Gio
 
 from .cache import cached
 
@@ -82,6 +82,17 @@ def is_file_dir(string):
     return os.path.isdir(string)
 
 
+def get_file_icon(path):
+    return (
+        Gio.file_new_for_path(path)
+        .query_info(
+            Gio.FILE_ATTRIBUTE_STANDARD_ICON,
+            Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
+        )
+        .get_icon()
+    )
+
+
 def is_flatpak():
     return os.path.exists(os.path.join(os.path.sep, ".flatpak-info"))
 
@@ -106,3 +117,12 @@ def get_size_for_humans(num):
             return "%3.1f %sB" % (num, unit)
         num /= 1000.0
     return "%.1f%sB" % (num, "Y")
+
+
+def find_child_by_id(container, child_id):
+    for widget in list(container):
+        if widget.get_buildable_id() == child_id:
+            return widget
+        if child := find_child_by_id(widget, child_id):
+            return child
+    return None
